//
//  GameViewController.m
//  GeometriesDemo
//
//  Created by Christoph Wick on 24/09/14.
//  Copyright (c) 2014 Christoph Wick, i4innovation GmbH. All rights reserved.
//

#import "GameViewController.h"

@implementation GameViewController

-(void)awakeFromNib
{
    // create a new scene
//    SCNScene *scene = [SCNScene sceneNamed:@"art.scnassets/ship.dae"];
    SCNScene *scene = [SCNScene scene];
    
    // create and add a camera to the scene
    SCNNode *cameraNode = [SCNNode node];
	SCNCamera *camera = [SCNCamera camera];
	camera.xFov = 40.0;
    cameraNode.camera = camera;
    [scene.rootNode addChildNode:cameraNode];
    
    // place the camera
    cameraNode.position = SCNVector3Make(0.0, 0.0, 40.0);
    
    // create and add a light to the scene
    SCNNode *lightNode = [SCNNode node];
    lightNode.light = [SCNLight light];
    lightNode.light.type = SCNLightTypeOmni;
    lightNode.position = SCNVector3Make(0, 10, 10);
    [scene.rootNode addChildNode:lightNode];
    
    // create and add an ambient light to the scene
    SCNNode *ambientLightNode = [SCNNode node];
    ambientLightNode.light = [SCNLight light];
    ambientLightNode.light.type = SCNLightTypeAmbient;
    ambientLightNode.light.color = [NSColor darkGrayColor];
    [scene.rootNode addChildNode:ambientLightNode];
	
	// create master node
	SCNNode *masterNode = [SCNNode node];
	masterNode.position = SCNVector3Make(-9.5, 0.0, 0.0);
	float masterNodeScale = 3.0;
	masterNode.scale = SCNVector3Make(masterNodeScale, masterNodeScale, masterNodeScale);
	masterNode.rotation = SCNVector4Make(1.0, 0.0, 0.0, M_PI/6);
	[scene.rootNode addChildNode:masterNode];
	
	
    // Create the box geometry and node
    SCNBox *box = [SCNBox boxWithWidth:1.0 height:1.0 length:1-0 chamferRadius:0.05];
    box.firstMaterial.diffuse.contents = [NSColor blueColor];
    box.firstMaterial.specular.contents = [NSColor blueColor];
    
    SCNNode *boxNode = [SCNNode nodeWithGeometry:box];
    boxNode.position = SCNVector3Make(0.0, 0.0, 0.0);
    [masterNode addChildNode:boxNode];

    // Create the sphere geometry and node
    SCNSphere *sphere = [SCNSphere sphereWithRadius:0.5];
    sphere.firstMaterial.diffuse.contents = [NSColor redColor];
    sphere.firstMaterial.specular.contents = [NSColor redColor];
    
    SCNNode *sphereNode = [SCNNode nodeWithGeometry:sphere];
    sphereNode.position = SCNVector3Make(1.1, 0.0, 0.0);
    [masterNode addChildNode:sphereNode];
    
    // Create the pyramid geometry and node
    SCNPyramid *pyramid = [SCNPyramid pyramidWithWidth:0.9 height:1.0 length:1.0];
    pyramid.firstMaterial.diffuse.contents = [NSColor greenColor];
    pyramid.firstMaterial.specular.contents = [NSColor greenColor];
    
    SCNNode *pyramidNode = [SCNNode nodeWithGeometry:pyramid];
    pyramidNode.position = SCNVector3Make(2.0, -0.5, 0.0);
    [masterNode addChildNode:pyramidNode];

    // Create the cone geometry and node
    SCNCone *cone = [SCNCone coneWithTopRadius:0.2 bottomRadius:0.45 height:1.0];
    cone.firstMaterial.diffuse.contents = [NSColor yellowColor];
    cone.firstMaterial.specular.contents = [NSColor yellowColor];
    
    SCNNode *coneNode = [SCNNode nodeWithGeometry:cone];
    coneNode.position = SCNVector3Make(3.0, 0.0, 0.0);
    [masterNode addChildNode:coneNode];
    
    // Create the cylinder geometry and node
    SCNCylinder *cylinder = [SCNCylinder cylinderWithRadius:0.45 height:1.0];

    cylinder.firstMaterial.diffuse.contents = [NSColor magentaColor];
    cylinder.firstMaterial.specular.contents = [NSColor magentaColor];
    
    SCNNode *cylinderNode = [SCNNode nodeWithGeometry:cylinder];
    cylinderNode.position = SCNVector3Make(4.0, 0.0, 0.0);
    [masterNode addChildNode:cylinderNode];
    
    // Create the capsule geometry and node
    SCNCapsule *capsule = [SCNCapsule capsuleWithCapRadius:0.35 height:1.2];
    
    capsule.firstMaterial.diffuse.contents = [NSColor cyanColor];
    capsule.firstMaterial.specular.contents = [NSColor cyanColor];
    
    SCNNode *capsulerNode = [SCNNode nodeWithGeometry:capsule];
    capsulerNode.position = SCNVector3Make(5.0, 0.0, 0.0);
    [masterNode addChildNode:capsulerNode];

    // Create the tube geometry and node
    SCNTube *tube = [SCNTube tubeWithInnerRadius:0.3 outerRadius:0.45 height:1.2];
    tube.firstMaterial.diffuse.contents = [NSColor orangeColor];
    tube.firstMaterial.specular.contents = [NSColor orangeColor];
    
    SCNNode *tubeNode = [SCNNode nodeWithGeometry:tube];
    tubeNode.position = SCNVector3Make(6.0, 0.0, 0.0);
    tubeNode.rotation = SCNVector4Make(1.0, 0.0, 0.0, M_PI/2);
    [masterNode addChildNode:tubeNode];
    
    // Create the torus geometry and node
    SCNTorus *torus = [SCNTorus torusWithRingRadius:0.35 pipeRadius:0.175];
    torus.firstMaterial.diffuse.contents = [NSColor brownColor];
    torus.firstMaterial.specular.contents = [NSColor brownColor];
    
    SCNNode *torusNode = [SCNNode nodeWithGeometry:torus];
    torusNode.position = SCNVector3Make(7.0, 0.0, 0.0);
    torusNode.rotation = SCNVector4Make(1.0, 0.0, 0.0, M_PI/4);
    [masterNode addChildNode:torusNode];

	// Create the text geometry and node
	SCNText *text = [SCNText textWithString:@"Hello Macoun" extrusionDepth:5.0];
	text.firstMaterial.diffuse.contents = [NSColor grayColor];
	text.firstMaterial.specular.contents = [NSColor grayColor];
	
	SCNNode *textNode = [SCNNode nodeWithGeometry:text];
	textNode.position = SCNVector3Make(0.0, -1.6, 1.0);
	textNode.scale = SCNVector3Make(0.03, 0.03, 0.03);
	textNode.rotation = SCNVector4Make(1.0, 0.0, 0.0, -M_PI/4);

	[masterNode addChildNode:textNode];

    // set the scene to the view
    self.gameView.scene = scene;
    
    // allows the user to manipulate the camera
    self.gameView.allowsCameraControl = YES;
    
    // show statistics such as fps and timing information
    self.gameView.showsStatistics = YES;
    
    // configure the view
    self.gameView.backgroundColor = [NSColor whiteColor];
}

@end
